"""
Contains a class PyYtData having implementation of youtube data v3 client.
"""

import os
import webbrowser
import json

from apiclient.discovery import build

from util.vidinfo import VidInfo


class PyYtData:
    """
    Class which acts as a client to the youtube data v3 API,
    having attributes as the query parameter for API.
    """

    def __init__(self, keyword, maxlen, order="relevance", type="video"):
        self.keyword = keyword
        self.order = order
        self.maxlen = maxlen
        self.type = type

    def get_videoinfo(self):
        """Returns a list with has objects of VidInfo class"""
        rslt = []

        for i in range(self.maxlen):
            vid = VidInfo(self.keyword, self.maxlen, i, self.order, self.type)
            rslt.append(vid)
        return rslt



import os
from setuptools import setup, find_packages


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name="pyytdata",
    version="0.1.9",
    author="Prince Roshan",
    author_email="princekrroshan01@gmail.com",
    url="https://github.com/princekrroshan01/youtube-api-wrapper",
    description=("this is a simple client for youtube data api v3"),
    long_description=read("README.rst"),
    license="MIT",
    packages=['pyytdata'],
    keywords=[
        "youtube-api" "recommend-youtube-videos",
        "youtube-data",
        "python",
        "wrapper",
        "youtube-data-api-v3",
        "youtube-api-wrapper",
        "youtube-api-v3",
    ],
    python_requires=">=3.6",
    install_requires=["google-api-python-client"],
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
)
